==> kima-trinity-14.1.1.tar.xz: kima-trinity-14.1.1/src/flowlayout.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef FLOWLAYOUT_H
#define FLOWLAYOUT_H

#include <tqlayout.h>
#include <tqptrlist.h>

class Source;
class TDEConfig;

class FlowLayout : public TQLayout{
	TQ_OBJECT
	 //macro which activates signals and slots (moc)
public:
	/**
	 * the direction for moveItem
	 */
	enum DIRECTION {
		ABOVE = 0,
		BELOW = 1
	};
	FlowLayout( TQWidget* parent, Qt::Orientation orientation=Qt::Horizontal, int border=0, int space=-1, const char* name=0 );
	FlowLayout( TQLayout* parent, Qt::Orientation orientation=Qt::Horizontal, int space=-1, const char* name=0 );
	FlowLayout( Qt::Orientation=Qt::Horizontal, int space=-1, const char* name=0 );
	virtual ~FlowLayout();
	/**
	 * tells all sources their positions
	 */
	void updatePositions(TDEConfig * inTDEConfig);
	void addItem(TQLayoutItem* item);
	void addSource(Source* src);
	void remove(TQWidget* widget);
	/**
	 * Returns the number of items in the layout
	 */
	uint count();
	/**
	 * moves the item \c which above/beneath item \c relate
	 * \param dir ABOVE if above, BENEATH if beneath
	 * \return the new Position or -1 if no real move was made
	 */
	bool moveItem(const TQLayoutItem* which, const TQLayoutItem* relate, DIRECTION direction);
	bool hasHeightForWidth() const;
	int heightForWidth(int w) const;
	bool hasWidthForHeight() const;
	int widthForHeight(int h) const;
	TQSize sizeHint() const;
	TQSize minimumSize() const;
	TQLayoutIterator iterator();
	TQSizePolicy::ExpandData expanding() const;
	Qt::Orientation getOrientation() const;

public slots:
	void setOrientation(Qt::Orientation orientation);

protected:
	void setGeometry(const TQRect&);

private:
	int doLayout( const TQRect&, bool testOnly = FALSE );
	int doLayoutHorizontal( const TQRect&, bool testOnly );
	int doLayoutVertical( const TQRect&, bool testOnly );
	Qt::Orientation mOrientation;
	TQPtrList<TQLayoutItem> mLayoutItems;
	// this is the connection between a layout item and its source.
	TQMap<TQLayoutItem*, Source*> mSources;
	TQLayoutItem* mLastItem; // the item that was last added
};
#endif

==> kima-trinity-14.1.2.tar.xz: kima-trinity-14.1.2/src/flowlayout.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef FLOWLAYOUT_H
#define FLOWLAYOUT_H

#include <tqlayout.h>
#include <tqptrlist.h>

class Source;
class TDEConfig;

class FlowLayout : public TQLayout{
	TQ_OBJECT
	 //macro which activates signals and slots (moc)
public:
	/**
	 * the direction for moveItem
	 */
	enum DIRECTION {
		ABOVE = 0,
		BELOW = 1
	};
	FlowLayout( TQWidget* parent, TQt::Orientation orientation=TQt::Horizontal, int border=0, int space=-1, const char* name=0 );
	FlowLayout( TQLayout* parent, TQt::Orientation orientation=TQt::Horizontal, int space=-1, const char* name=0 );
	FlowLayout( TQt::Orientation=TQt::Horizontal, int space=-1, const char* name=0 );
	virtual ~FlowLayout();
	/**
	 * tells all sources their positions
	 */
	void updatePositions(TDEConfig * inTDEConfig);
	void addItem(TQLayoutItem* item);
	void addSource(Source* src);
	void remove(TQWidget* widget);
	/**
	 * Returns the number of items in the layout
	 */
	uint count();
	/**
	 * moves the item \c which above/beneath item \c relate
	 * \param dir ABOVE if above, BENEATH if beneath
	 * \return the new Position or -1 if no real move was made
	 */
	bool moveItem(const TQLayoutItem* which, const TQLayoutItem* relate, DIRECTION direction);
	bool hasHeightForWidth() const;
	int heightForWidth(int w) const;
	bool hasWidthForHeight() const;
	int widthForHeight(int h) const;
	TQSize sizeHint() const;
	TQSize minimumSize() const;
	TQLayoutIterator iterator();
	TQSizePolicy::ExpandData expanding() const;
	TQt::Orientation getOrientation() const;

public slots:
	void setOrientation(TQt::Orientation orientation);

protected:
	void setGeometry(const TQRect&);

private:
	int doLayout( const TQRect&, bool testOnly = FALSE );
	int doLayoutHorizontal( const TQRect&, bool testOnly );
	int doLayoutVertical( const TQRect&, bool testOnly );
	TQt::Orientation mOrientation;
	TQPtrList<TQLayoutItem> mLayoutItems;
	// this is the connection between a layout item and its source.
	TQMap<TQLayoutItem*, Source*> mSources;
	TQLayoutItem* mLastItem; // the item that was last added
};
#endif
